@@ -1,6 +1,7 @@
 from abc import ABC
 from abc import abstractmethod
 from pathlib import Path
+from typing import Dict
 from typing import Iterator
 from typing import List
 from typing import Optional
@@ -10,7 +11,10 @@ from jinja2 import Environment
 from jinja2 import FileSystemLoader
 from jinja2 import Template
 
-from xsdata.models.codegen import Class
+from xsdata.codegen.models import Class
+from xsdata.utils.collections import group_by
+from xsdata.utils.package import module_path
+from xsdata.utils.package import package_path
 
 
 class AbstractGenerator(ABC):
@@ -35,3 +39,11 @@ class AbstractGenerator(ABC):
     @classmethod
     def package_name(cls, name: str) -> str:
         return name
+
+    @classmethod
+    def group_by_package(cls, classes: List[Class]) -> Dict[Path, List[Class]]:
+        return group_by(classes, lambda x: package_path(x.target_module))
+
+    @classmethod
+    def group_by_module(cls, classes: List[Class]) -> Dict[Path, List[Class]]:
+        return group_by(classes, lambda x: module_path(x.target_module))
