@@ -1,4 +1,7 @@
+from collections import defaultdict
 from typing import Any
+from typing import Callable
+from typing import Dict
 from typing import List
 from typing import Optional
 from typing import Sequence
@@ -18,3 +21,10 @@ def unique_sequence(items: Sequence, key: Optional[str] = None) -> List:
         return True
 
     return [item for item in items if is_new(item)]
+
+
+def group_by(items: Sequence, key: Callable) -> Dict[Any, List]:
+    result = defaultdict(list)
+    for item in items:
+        result[key(item)].append(item)
+    return result
